@@ -1,6 +1,6 @@
 package Reflex::Event;
 {
-  $Reflex::Event::VERSION = '0.098';
+  $Reflex::Event::VERSION = '0.099';
 }
 
 use Moose;
@@ -130,7 +130,7 @@ sub dump {
 	my $dump = "=== $self ===\n";
 	my %clone = ($self->_headers(), $self->_body());
 	foreach my $k (sort keys %clone) {
-		$dump .= "$k: $clone{$k}\n";
+		$dump .= "  $k: " . ($clone{$k} // '(undef)') . "\n";
 		if ($k eq '-emitters') {
 			my @emitters = $self->get_all_emitters();
 			for my $i (0..$#emitters) {
@@ -159,7 +159,7 @@ __END__
 
 =head1 VERSION
 
-This document describes version 0.098, released on June 05, 2012.
+This document describes version 0.099, released on April 21, 2013.
 
 =head1 SEE ALSO
 
@@ -184,7 +184,7 @@ Rocco Caputo <rcaputo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Rocco Caputo.
+This software is copyright (c) 2013 by Rocco Caputo.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
