@@ -1,6 +1,6 @@
 package Reflex::Role::Encoding;
 {
-  $Reflex::Role::Encoding::VERSION = '0.098';
+  $Reflex::Role::Encoding::VERSION = '0.099';
 }
 # vim: ts=2 sw=2 noexpandtab
 
@@ -36,7 +36,7 @@ role {
 			$message->is_combinable() and
 			$self->messages()->[-1]->is_combinable()
 		) {
-			$self->messages()->[-1]->absorb($message);
+			$self->messages()->[-1]->append($message);
 			return;
 		}
 
@@ -55,7 +55,7 @@ __END__
 
 =head1 VERSION
 
-This document describes version 0.098, released on June 05, 2012.
+This document describes version 0.099, released on April 21, 2013.
 
 =head1 SEE ALSO
 
@@ -80,7 +80,7 @@ Rocco Caputo <rcaputo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Rocco Caputo.
+This software is copyright (c) 2013 by Rocco Caputo.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
