@@ -1,6 +1,6 @@
 package Reflex::Trait::EmitsOnChange;
 {
-  $Reflex::Trait::EmitsOnChange::VERSION = '0.098';
+  $Reflex::Trait::EmitsOnChange::VERSION = '0.099';
 }
 # vim: ts=2 sw=2 noexpandtab
 
@@ -80,6 +80,7 @@ has initializer => (
 has event => (
 	isa     => 'Str',
 	is      => 'ro',
+	lazy    => 1,
 	default => sub {
 		my $self = shift;
 		return $self->name();
@@ -98,7 +99,7 @@ sub emits {
 
 package Moose::Meta::Attribute::Custom::Trait::Reflex::Trait::EmitsOnChange;
 {
-  $Moose::Meta::Attribute::Custom::Trait::Reflex::Trait::EmitsOnChange::VERSION = '0.098';
+  $Moose::Meta::Attribute::Custom::Trait::Reflex::Trait::EmitsOnChange::VERSION = '0.099';
 }
 sub register_implementation { 'Reflex::Trait::EmitsOnChange' }
 
@@ -118,7 +119,7 @@ Reflex::Trait::EmitsOnChange - Emit an event when an attribute's value changes.
 
 =head1 VERSION
 
-This document describes version 0.098, released on June 05, 2012.
+This document describes version 0.099, released on April 21, 2013.
 
 =head1 SYNOPSIS
 
@@ -250,7 +251,7 @@ Rocco Caputo <rcaputo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Rocco Caputo.
+This software is copyright (c) 2013 by Rocco Caputo.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
