@@ -1,6 +1,6 @@
 package Reflex::Trait::Watched;
 {
-  $Reflex::Trait::Watched::VERSION = '0.098';
+  $Reflex::Trait::Watched::VERSION = '0.099';
 }
 # vim: ts=2 sw=2 noexpandtab
 
@@ -85,6 +85,7 @@ has initializer => (
 has role => (
 	isa     => 'Str',
 	is      => 'ro',
+	lazy    => 1,
 	default => sub {
 		my $self = shift;
 		return $self->name();
@@ -124,7 +125,7 @@ sub watches {
 
 package Moose::Meta::Attribute::Custom::Trait::Reflex::Trait::Watched;
 {
-  $Moose::Meta::Attribute::Custom::Trait::Reflex::Trait::Watched::VERSION = '0.098';
+  $Moose::Meta::Attribute::Custom::Trait::Reflex::Trait::Watched::VERSION = '0.099';
 }
 sub register_implementation { 'Reflex::Trait::Watched' }
 
@@ -144,7 +145,7 @@ Reflex::Trait::Watched - Automatically watch Reflex objects.
 
 =head1 VERSION
 
-This document describes version 0.098, released on June 05, 2012.
+This document describes version 0.099, released on April 21, 2013.
 
 =head1 SYNOPSIS
 
@@ -267,7 +268,7 @@ Rocco Caputo <rcaputo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Rocco Caputo.
+This software is copyright (c) 2013 by Rocco Caputo.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
